==> eiffelstudio-18.11.10.2592.tar: F_code/C10/xm488.c <==
/*
 * Code for class XM_XSLT_PI_CHOOSER_BY_NAME
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm488.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_PI_CHOOSER_BY_NAME}.make */
void F1174_8886 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F1174_8889(Current, arg1);
}

/* {XM_XSLT_PI_CHOOSER_BY_NAME}.name */
EIF_REFERENCE F1174_8887 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {XM_XSLT_PI_CHOOSER_BY_NAME}.selected_index */
EIF_INTEGER_32 F1174_8888 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc2 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,arg1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L))) {
		RTLE;
		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	} else {
		Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R9408[Dtype(arg1)-1394])(RTCW(arg1));
		F1277_11088(RTCW(loc1));
		for (;;) {
			tb1 = '\01';
			if (!loc2) {
				tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R3132[Dtype(loc1)-430])(RTCW(loc1));
				tb1 = tb2;
			}
			if (tb1) break;
			tr1 = RTOSCF(8261,F1130_8261,(Current));
			tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R3131[Dtype(loc1)-534])(RTCW(loc1));
			tr3 = *(EIF_REFERENCE *)(Current);
			tb2 = F1115_8100(RTCW(tr1), tr2, tr3);
			if (tb2) {
				loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			}
			if (loc2) {
				Result = F1328_11143(RTCW(loc1));
				F1277_11091(RTCW(loc1));
			} else {
				F1277_11089(RTCW(loc1));
			}
		}
	}
	RTLE;
	return Result;
}

/* {XM_XSLT_PI_CHOOSER_BY_NAME}.set_name */
void F1174_8889 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
}

void EIF_Minit488 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C10/xm488.c <==
/*
 * Code for class XM_XSLT_PI_CHOOSER_BY_NAME
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm488.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_PI_CHOOSER_BY_NAME}.make */
void F1174_8917 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F1174_8920(Current, arg1);
}

/* {XM_XSLT_PI_CHOOSER_BY_NAME}.selected_index */
EIF_INTEGER_32 F1174_8919 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc2 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,arg1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L))) {
		RTLE;
		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	} else {
		Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R9433[Dtype(RTCW(arg1))-1400])(arg1);
		F1283_11121(RTCW(loc1));
		for (;;) {
			tb1 = '\01';
			if (!loc2) {
				tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R3134[Dtype(RTCW(loc1))-430])(loc1);
				tb1 = tb2;
			}
			if (tb1) break;
			tr1 = RTOSCF(8292,F1130_8292, (Current));
			tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R3133[Dtype(RTCW(loc1))-534])(loc1);
			tr3 = *(EIF_REFERENCE *)(Current);
			tb2 = F1115_8131(RTCW(tr1), tr2, tr3);
			if (tb2) {
				loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			}
			if (loc2) {
				Result = F1334_11176(RTCW(loc1));
				F1283_11124(RTCW(loc1));
			} else {
				F1283_11122(RTCW(loc1));
			}
		}
	}
	RTLE;
	return Result;
}

/* {XM_XSLT_PI_CHOOSER_BY_NAME}.set_name */
void F1174_8920 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
}

void EIF_Minit488 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
